"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sequelize_typescript_1 = require("sequelize-typescript");
const dot_statistic_model_1 = __importDefault(require("../models/dot_statistic_model"));
const moment_1 = __importDefault(require("moment"));
const logUtil_1 = require("../utils/logUtil");
class DotStatisticDao {
    /**
     * 创建Temp Res数据
     * @param data
     * @returns {Promise<*>}
     */
    static createDotStatistic(data) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            let rlt = undefined;
            // const transaction = await sequelize.Transaction;
            // const user = await User.findOne(..., { transaction });
            // await user.update(..., { transaction });
            const trans = yield ((_a = dot_statistic_model_1.default.sequelize) === null || _a === void 0 ? void 0 : _a.transaction());
            if (trans) {
                try {
                    rlt = yield dot_statistic_model_1.default.bulkCreate(data, { transaction: trans });
                    trans.commit();
                    (0, logUtil_1.localLog)('我提交了，然后呢？');
                }
                catch (ex) {
                    (0, logUtil_1.localLogErr)("error:", ex.message);
                    trans.rollback();
                }
            }
            // const rlt = await entities.save()
            return rlt;
        });
    }
    static removeDotStatistic(ids) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            let rlt = 0;
            let trans = yield ((_a = dot_statistic_model_1.default.sequelize) === null || _a === void 0 ? void 0 : _a.transaction());
            if (trans) {
                try {
                    for (let i = 0; i < ids.length; i++) {
                        rlt = yield dot_statistic_model_1.default.destroy({
                            where: {
                                id: ids[i],
                            },
                            transaction: trans
                        });
                    }
                    trans.commit();
                }
                catch (ex) {
                    (0, logUtil_1.localLogErr)('error:', ex.message);
                    trans.rollback();
                }
            }
            return rlt;
        });
    }
    /**
     * 查询详情数据
     * @param id  id
     * @returns {Promise<Model>}
     */
    static getTempResDetail(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const rlt = yield dot_statistic_model_1.default.findOne({
                where: {
                    id,
                },
            });
            return rlt;
        });
    }
    /**
     * 分页查询
     * @param pageIdx 页索引
     * @param pageSize 页大小
     * @returns {Promise<Model>}
     */
    static getAllList(params) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!params.opdate || !params.events || params.events.length === 0) {
                return null;
            }
            const where = {
                event: params && params.events ? {
                    [sequelize_typescript_1.Sequelize.Op.in]: params.events,
                } : undefined,
                appName: params && params.appNames ? {
                    [sequelize_typescript_1.Sequelize.Op.in]: params.appNames,
                } : undefined,
                category: params && params.categories ? {
                    [sequelize_typescript_1.Sequelize.Op.in]: params.categories,
                } : undefined,
                opdate: params && params.opdate ? params.opdate : undefined,
            };
            if (!where.event)
                delete where.event;
            if (!where.category)
                delete where.category;
            if (!where.appName)
                delete where.appName;
            if (!where.opdate)
                delete where.opdate;
            const rows = yield dot_statistic_model_1.default.findAll({
                where,
            });
            rows.forEach(item => {
                item.val1 = Number(item.val1 || 0);
                item.val2 = Number(item.val2 || 0);
                item.val3 = Number(item.val3 || 0);
                item.createTime = Number(item.createTime || 0);
                item.updateTime = Number(item.updateTime || 0);
            });
            return rows;
        });
    }
    /**
     * 分页查询
     * @param pageIdx 页索引
     * @param pageSize 页大小
     * @returns {Promise<Model>}
     */
    static getList(pageIdx, pageSize, params) {
        return __awaiter(this, void 0, void 0, function* () {
            let offset = (pageIdx - 1) * pageSize;
            if (offset < 0)
                offset = 0;
            let stTimeStamp = new Date('1900-01-01').getTime();
            if (params && params.createTimeSt) {
                stTimeStamp = Number((0, moment_1.default)(new Date(params.createTimeSt)).startOf('day').format('x'));
            }
            let endTimeStamp = new Date('2999-12-30').getTime();
            if (params && params.createTimeEnd) {
                endTimeStamp = Number((0, moment_1.default)(new Date(params.createTimeEnd)).endOf('day').format('x'));
            }
            const where = {
                event: params && params.event ? {
                    [sequelize_typescript_1.Sequelize.Op.like]: '%' + params.event + '%',
                } : undefined,
                createTime: {
                    [sequelize_typescript_1.Sequelize.Op.gt]: stTimeStamp,
                    [sequelize_typescript_1.Sequelize.Op.lt]: endTimeStamp,
                },
                opdate: params && params.opdate ? params.opdate : undefined,
                appName: params && params.appName ? {
                    [sequelize_typescript_1.Sequelize.Op.like]: '%' + params.appName + '%',
                } : undefined,
                category: params && params.category ? {
                    [sequelize_typescript_1.Sequelize.Op.like]: '%' + params.category + '%',
                } : undefined,
            };
            if (!where.event)
                delete where.event;
            if (!where.category)
                delete where.category;
            if (!where.appName)
                delete where.appName;
            if (!where.opdate)
                delete where.opdate;
            const rlt = yield dot_statistic_model_1.default.findAndCountAll({
                where,
                offset,
                limit: pageSize,
            });
            if (rlt && rlt.rows) {
                rlt.rows.forEach(item => {
                    item.val1 = Number(item.val1 || 0);
                    item.val2 = Number(item.val2 || 0);
                    item.val3 = Number(item.val3 || 0);
                    item.createTime = Number(item.createTime || 0);
                    item.updateTime = Number(item.updateTime || 0);
                });
            }
            return rlt;
        });
    }
}
exports.default = DotStatisticDao;
