"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getImpalaTblNameFromPrdLineCode = exports.getImpalaTblName = exports.joinArrStr = exports.execImpalaSql = exports.ENUM_IMPLALA_COLUMN_TYPES = void 0;
const logUtil_1 = require("../utils/logUtil");
const base_1 = require("./base");
// console.log('0000000000000000', myEncrypt('Tzwpblog.2021'), myDecrypt('U2FsdGVkX18bFfVfYkLw/yiaCMm8PxbWF6qPLAcJpyc='), myDecrypt('U2FsdGVkX18JhFNfxOjD6nQ01EuHtaD8iI2i92bOkew='))
const client = require('hs2-thrift');
const cfgFileName = process.env.NODE_ENV || "development";
const dataJSON = require(`../config/${cfgFileName}.json`);
const config = {
    host: dataJSON.impalaDbHost,
    port: dataJSON.impalaDbPort,
    username: dataJSON.impalaDbUserName,
    password: (0, base_1.myDecrypt)(dataJSON.impalaDbPWD),
    protocol_ver: 5,
    retain_session: null // Set true if you want to retain connection and session
};
var ENUM_IMPLALA_COLUMN_TYPES;
(function (ENUM_IMPLALA_COLUMN_TYPES) {
    ENUM_IMPLALA_COLUMN_TYPES["NUMBER"] = "number";
    ENUM_IMPLALA_COLUMN_TYPES["STRING"] = "string";
})(ENUM_IMPLALA_COLUMN_TYPES = exports.ENUM_IMPLALA_COLUMN_TYPES || (exports.ENUM_IMPLALA_COLUMN_TYPES = {}));
function execImpalaSql(sql, cols) {
    return __awaiter(this, void 0, void 0, function* () {
        let session = null;
        let rltTbl = new Array();
        let errorStr = '';
        try {
            session = yield client.connect(config);
            (0, logUtil_1.localLog)('Session created.');
            const tblRows = yield client.query(session, sql);
            /** 从列中筛选数据 */
            // console.log('444444444444444444', tblRows, cols)
            for (let i = 0; i < tblRows.length; i++) {
                let row = tblRows[i];
                let rltRow = new Map();
                for (let j = 0; j < cols.length; j++) {
                    let col = cols[j];
                    let colName = String(col.name);
                    let colType = String(col.type);
                    for (let k = 0; k < row.length; k++) {
                        for (let key in row[k]) {
                            if (key === colName) {
                                let vBuffer = row[k][colName];
                                // console.log('Result2: ', colName, colType, vBuffer, typeof vBuffer)
                                if (colType === ENUM_IMPLALA_COLUMN_TYPES.NUMBER) {
                                    let num = vBuffer.toString(10);
                                    // console.log('5555555555555555555', num)
                                    rltRow.set(colName, num);
                                }
                                else {
                                    let str = String(vBuffer);
                                    // console.log('6666666666666666666', str)
                                    rltRow.set(colName, str);
                                }
                                break;
                            }
                        }
                    }
                }
                rltTbl.push(rltRow);
            }
            if (config.retain_session == null) {
                yield client.disconnect(session);
                (0, logUtil_1.localLogErr)('Disconnected from server and closed session successfully.');
            }
        }
        catch (error) {
            rltTbl = null;
            errorStr = JSON.stringify(error);
            (0, logUtil_1.localLogErr)('Error: ' + errorStr);
            if (session) {
                yield client.disconnect(session);
            }
        }
        if (rltTbl) {
            return {
                Result: 1,
                code: 200,
                data: rltTbl,
            };
        }
        else {
            return {
                Result: 0,
                code: 500,
                message: errorStr
            };
        }
    });
}
exports.execImpalaSql = execImpalaSql;
function joinArrStr(strArr = []) {
    const rlt = "'" + strArr.join("','") + "'";
    return rlt;
}
exports.joinArrStr = joinArrStr;
function getImpalaTblName(appname) {
    let tblName = '';
    switch (appname) {
        case 'vidnow':
            tblName = 'pipeline_analyze_event_contents';
            break;
        default:
            tblName = 'pipeline_analyze_event';
            break;
    }
    return tblName;
}
exports.getImpalaTblName = getImpalaTblName;
/**按照产品线Code获取impala的表名 */
function getImpalaTblNameFromPrdLineCode(prdLineCode) {
    let tblName = '';
    switch (prdLineCode.toLowerCase()) {
        case 'cont':
        case 'vidnow':
            tblName = 'pipeline_analyze_event_contents';
            break;
        default:
            tblName = 'pipeline_analyze_event';
            break;
    }
    return tblName;
}
exports.getImpalaTblNameFromPrdLineCode = getImpalaTblNameFromPrdLineCode;
