"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const moment_1 = __importDefault(require("moment"));
const dot_task_campaign_1 = __importDefault(require("../campaign/dot_task_campaign"));
const impalaHelper_1 = require("../db/impalaHelper");
const dot_task_model_1 = require("../models/dot_task_model");
const utils_1 = require("../utils");
const logUtil_1 = require("../utils/logUtil");
const impalaTaskRouter = require('koa-router')();
// 加入查询队列
impalaTaskRouter.post('/pushQueryTask', (ctx, next) => __awaiter(void 0, void 0, void 0, function* () {
    const postData = ctx.request.body;
    //log
    (0, logUtil_1.localLog)('/pushQueryTask pre => ', JSON.stringify(postData));
    if (!(postData instanceof Array)) {
        ctx.body = {
            Result: 0,
            code: 0,
            // data: [],
            message: 'unknown_format'
        };
        return;
    }
    for (let i = 0; i < postData.length; i++) {
        const eventsStr = JSON.stringify(postData[i].events);
        const fieldLimits = [
            {
                key: 'eventsStr',
                val: eventsStr,
                limit: 4500
            }, {
                key: 'appName',
                val: postData[i].appName,
                limit: 200
            }, {
                key: 'batchId',
                val: postData[i].batchId,
                limit: 200
            }, {
                key: 'opdate',
                val: postData[i].opdate,
                limit: 10
            }, {
                key: 'category',
                val: postData[i].opdate,
                limit: 200
            }
        ];
        for (let j = 0; j < fieldLimits.length; j++) {
            if (fieldLimits[j].val.length > fieldLimits[j].limit) {
                ctx.body = {
                    Result: 0,
                    code: 0,
                    // data: [],
                    message: `field_length_limit_${fieldLimits[j].limit} ${fieldLimits[j].key}`
                };
                return;
            }
        }
        if (postData[i].events.length > 30) {
            ctx.body = {
                Result: 0,
                code: 0,
                // data: [],
                message: `field_length_limit_30items events`
            };
            return;
        }
    }
    //log
    (0, logUtil_1.localLog)('/pushQueryTask todo => ', JSON.stringify(postData));
    const dateNow = new Date();
    const newList = [];
    postData.forEach(item => {
        const tblName = (0, impalaHelper_1.getImpalaTblName)(item.appName);
        const eventsStr = JSON.stringify(item.events);
        const eventsStrInSql = eventsStr.replace('[', '(').replace(']', ')');
        newList.push({
            id: (0, utils_1.getGuid)(),
            batchId: item.batchId,
            category: item.category,
            appName: item.appName,
            eventsStr: eventsStr,
            opdate: item.opdate,
            actTimeRangeStart: Number((0, moment_1.default)(dateNow).startOf('day').format('x')),
            // opdate: 
            // actTimeRangeEnd: Number(moment(dateNow).endOf('day').format('x')),
            impalaQuerySql: `select event,count(DISTINCT userid) as userdotcnt,count(1) as dotcnt from dt_crawler.${tblName} pn where appname='${item.appName}' and opdate='${item.opdate}' and event in ${eventsStrInSql} group by event`,
            impalaRltDataSetType: dot_task_model_1.ENUM_IMPALA_RLT_DATASET_TYPE.TO_MYSQL_STATISTICS_TABLE,
            createTime: dateNow.getTime(),
            updateTime: dateNow.getTime()
        });
    });
    try {
        const res = yield dot_task_campaign_1.default.createDotTask(newList);
        if (res && res.length === postData.length) {
            //log
            (0, logUtil_1.localLog)('/pushQueryTask success => ', JSON.stringify(postData));
            ctx.body = {
                Result: 1,
                code: 200,
                data: res,
            };
        }
        else {
            //log
            (0, logUtil_1.localLog)('/pushQueryTask fail => ', JSON.stringify(postData));
            ctx.body = {
                Result: 0,
                code: 0,
                // data: [],
                message: 'unknown_err'
            };
        }
    }
    catch (e) {
        (0, logUtil_1.localLog)('/pushQueryTask fail => ', e.message);
        ctx.body = {
            Result: 0,
            code: 0,
            // data: [],
            message: 'error:' + e.message
        };
    }
}));
// 报表任务加入查询队列
impalaTaskRouter.post('/pushRptQueryTask', (ctx, next) => __awaiter(void 0, void 0, void 0, function* () {
    const postData = ctx.request.body;
    //log
    (0, logUtil_1.localLog)('/pushQueryTask pre => ', JSON.stringify(postData));
    if (!(postData instanceof Array)) {
        ctx.body = {
            Result: 0,
            code: 0,
            // data: [],
            message: 'unknown_format'
        };
        return;
    }
    for (let i = 0; i < postData.length; i++) {
        const fieldLimits = [
            {
                key: 'impalaQuerysql',
                val: postData[i].impalaQuerysql,
                limit: 4500
            }, {
                key: 'prdlineCode',
                val: postData[i].prdlineCode,
                limit: 200
            }, {
                key: 'rptModId',
                val: postData[i].rptModId,
                limit: 200
            }, {
                key: 'opdate',
                val: postData[i].opdate,
                limit: 10
            }
        ];
        for (let j = 0; j < fieldLimits.length; j++) {
            if (fieldLimits[j].val.length > fieldLimits[j].limit) {
                ctx.body = {
                    Result: 0,
                    code: 0,
                    // data: [],
                    message: `field_length_limit_${fieldLimits[j].limit} ${fieldLimits[j].key}`
                };
                return;
            }
        }
    }
    //log
    (0, logUtil_1.localLog)('/pushQueryTask todo => ', JSON.stringify(postData));
    const dateNow = new Date();
    const newList = [];
    postData.forEach(item => {
        const tblName = (0, impalaHelper_1.getImpalaTblNameFromPrdLineCode)(item.prdlineCode);
        var _impalaQuerysql = item.impalaQuerysql.replace('${opdate}', item.opdate);
        newList.push({
            id: (0, utils_1.getGuid)(),
            batchId: item.batchId,
            prdlineCode: item.prdlineCode,
            rptModId: item.rptModId,
            opdate: item.opdate,
            actTimeRangeStart: Number((0, moment_1.default)(dateNow).startOf('day').format('x')),
            // opdate: 
            // actTimeRangeEnd: Number(moment(dateNow).endOf('day').format('x')),
            impalaQuerySql: _impalaQuerysql,
            impalaRltDataSetType: dot_task_model_1.ENUM_IMPALA_RLT_DATASET_TYPE.TO_MYSQL_RPT_STATISTICS_TABLE,
            createTime: dateNow.getTime(),
            updateTime: dateNow.getTime()
        });
    });
    try {
        const res = yield dot_task_campaign_1.default.createDotTask(newList);
        if (res && res.length === postData.length) {
            //log
            (0, logUtil_1.localLog)('/pushQueryTask success => ', JSON.stringify(postData));
            ctx.body = {
                Result: 1,
                code: 200,
                data: res,
            };
        }
        else {
            //log
            (0, logUtil_1.localLog)('/pushQueryTask fail => ', JSON.stringify(postData));
            ctx.body = {
                Result: 0,
                code: 0,
                // data: [],
                message: 'unknown_err'
            };
        }
    }
    catch (e) {
        (0, logUtil_1.localLog)('/pushQueryTask fail => ', e.message);
        ctx.body = {
            Result: 0,
            code: 0,
            // data: [],
            message: 'error:' + e.message
        };
    }
}));
// 获取我的查询队列
impalaTaskRouter.post('/getQueryTaskList', (ctx, next) => __awaiter(void 0, void 0, void 0, function* () {
    const postData = ctx.request.body;
    try {
        const res = yield dot_task_campaign_1.default.getList(postData.pageIdx, postData.pageSize, {
            opdate: postData.opdate,
            createTimeSt: postData.createTimeSt,
            createTimeEnd: postData.createTimeEnd,
            appname: postData.appName,
            category: postData.category,
            event: postData.event,
        });
        ctx.body = {
            Result: 1,
            code: 200,
            data: res.rows,
            pageIndex: postData.pageIdx,
            pageSize: postData.pageSize,
            totalCount: res.count,
        };
    }
    catch (e) {
        ctx.body = {
            Result: 0,
            code: 0,
            message: 'error:' + e.message,
            pageIndex: postData.pageIdx,
            pageSize: postData.pageSize,
            totalCount: 0,
        };
    }
}));
// 修改
// 删除
impalaTaskRouter.post('/delQueryTask', (ctx, next) => __awaiter(void 0, void 0, void 0, function* () {
    const postData = ctx.request.body;
    try {
        const delCnt = yield dot_task_campaign_1.default.removeDotTask(postData);
        if (delCnt > 0) {
            ctx.body = {
                Result: 1,
                code: 200,
                data: true
            };
        }
        else {
            ctx.body = {
                Result: 0,
                code: 0,
                message: 'error'
            };
        }
    }
    catch (e) {
        ctx.body = {
            Result: 0,
            code: 0,
            message: 'error:' + e.message
        };
    }
}));
// 添加 自测试通过
impalaTaskRouter.post('/testPushMySqlDotTask', (ctx, next) => __awaiter(void 0, void 0, void 0, function* () {
    const appname = 'vidnow';
    const category = 'vidnow_landing_page';
    const opdate = '2022-09-15';
    const batchId = "batchId1";
    const tblName = (0, impalaHelper_1.getImpalaTblName)(appname);
    const event1 = ['h5_event_open_url'];
    const event2 = ['h5_event_click_download'];
    // SELECT *
    //     from dt_crawler.pipeline_analyze_event_contents pn
    //     where opdate='2022-08-08'
    //     and appname = 'VidNow' and event='h5_event_open_url' and (properties not like '%tp=%')
    const dateNow = new Date();
    const dd = yield dot_task_campaign_1.default.createDotTask([{
            id: "id1",
            batchId: batchId,
            category: category,
            appName: appname,
            opdate: opdate,
            eventsStr: JSON.stringify(event1),
            actTimeRangeStart: Number((0, moment_1.default)(dateNow).startOf('day').format('x')),
            // actTimeRangeEnd: Number(moment(dateNow).endOf('day').format('x')),
            impalaQuerySql: `select event,count(distinct userid),count(1) from dt_crawler.${tblName} pn where opdate='${opdate}' and event in ${JSON.stringify(event1).replace('[', '(').replace(']', ')')} group by event`,
            impalaRltDataSetType: dot_task_model_1.ENUM_IMPALA_RLT_DATASET_TYPE.TO_MYSQL_STATISTICS_TABLE,
            // impalaExecStatus: ENUM_IMPALA_QUERY_EXEC_STATUS.UNSUNCCESSFUL,
            createTime: dateNow.getTime(),
            updateTime: dateNow.getTime()
        }, {
            id: "id2",
            batchId: batchId,
            category: category,
            appName: appname,
            opdate: opdate,
            eventsStr: JSON.stringify(event2),
            actTimeRangeStart: Number((0, moment_1.default)(dateNow).startOf('day').format('x')),
            // actTimeRangeEnd: Number(moment(dateNow).endOf('day').format('x')),
            impalaQuerySql: `select event,count(distinct userid),count(1) from dt_crawler.${tblName} pn where opdate='${opdate}' and event in ${JSON.stringify(event2).replace('[', '(').replace(']', ')')} group by event`,
            impalaRltDataSetType: dot_task_model_1.ENUM_IMPALA_RLT_DATASET_TYPE.TO_MYSQL_STATISTICS_TABLE,
            impalaExecStatus: dot_task_model_1.ENUM_IMPALA_QUERY_EXEC_STATUS.UNSUNCCESSFUL,
            createTime: dateNow.getTime(),
            updateTime: dateNow.getTime()
        }]);
    ctx.body = {
        title: 'testRemoveMySql'
    };
}));
// 删除自测试通过
impalaTaskRouter.post('/testRemoveMySqlDotTask', (ctx, next) => __awaiter(void 0, void 0, void 0, function* () {
    const dd = yield dot_task_campaign_1.default.removeDotTask(["id1", "id2"]);
    ctx.body = {
        title: 'testRemoveMySql'
    };
}));
module.exports = impalaTaskRouter;
